@@ -34,7 +34,7 @@
 #include "tests.h"
 #include "utils.h"
 
-static int serve_response(ne_socket *s, const char *response)
+int serve_response(ne_socket *s, const char *response)
 {
     CALL(discard_request(s));
     CALL(discard_body(s));
@@ -104,9 +104,18 @@ int any_2xx_request(ne_session *sess, const char *uri)
     ne_request *req = ne_request_create(sess, "GET", uri);
     int ret = ne_request_dispatch(req);
     int klass = ne_get_status(req)->klass;
+    const char *context = ne_get_response_header(req, "X-Neon-Context");
+    if (ret != NE_OK || klass != 2) {
+        if (context)
+            t_context("request failed, server error: %s", context);
+        else
+            t_context("request failed: %s", ne_get_error(sess));
+        ret = FAIL;
+    }
+    else {
+        ret = OK;
+    }
     ne_request_destroy(req);
-    ONV(ret != NE_OK || klass != 2,
-	("request failed: %s", ne_get_error(sess)));
     return ret;
 }
 
@@ -175,17 +184,24 @@ int full_write(ne_socket *sock, const char *data, size_t len)
     return OK;
 }
 
-int session_server(ne_session **sess, server_fn fn, void *userdata)
+int multi_session_server(ne_session **sess,
+                         const char *scheme, const char *hostname,
+                         int count, server_fn fn, void *userdata)
 {
     unsigned int port;
     
-    CALL(new_spawn_server(1, fn, userdata, &port));
+    CALL(new_spawn_server(count, fn, userdata, &port));
     
-    *sess = ne_session_create("http", "127.0.0.1", port);
+    *sess = ne_session_create(scheme, hostname, port);
 
     return OK;
 }
 
+int session_server(ne_session **sess, server_fn fn, void *userdata)
+{
+    return multi_session_server(sess, "http", "127.0.0.1", 1, fn, userdata);
+}
+
 int proxied_session_server(ne_session **sess, const char *scheme,
                            const char *host, unsigned int fakeport,
                            server_fn fn, void *userdata)
@@ -213,12 +229,21 @@ static void fakesess_destroy(void *userdata)
 int fakeproxied_session_server(ne_session **sess, const char *scheme,
                                const char *host, unsigned int fakeport,
                                server_fn fn, void *userdata)
+{
+    return fakeproxied_multi_session_server(1, sess, scheme, host, fakeport,
+                                            fn, userdata);
+}
+
+int fakeproxied_multi_session_server(int count,
+                                     ne_session **sess, const char *scheme,
+                                     const char *host, unsigned int fakeport,
+                                     server_fn fn, void *userdata)
 {
     unsigned int port;
     ne_inet_addr *addr;
     const ne_inet_addr *alist[1];
     
-    CALL(new_spawn_server2(1, fn, userdata, &addr, &port));
+    CALL(new_spawn_server2(count, fn, userdata, &addr, &port));
     
     alist[0] = addr;
 
